==> apache-fineract-1.8.4-src.tar.gz: apache-fineract-src-1.8.4/fineract-provider/src/main/java/org/apache/fineract/portfolio/savings/domain/SavingsAccountTransactionDataComparator.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.portfolio.savings.domain;

import java.util.Comparator;
import org.apache.fineract.portfolio.savings.data.SavingsAccountTransactionData;

public class SavingsAccountTransactionDataComparator implements Comparator<SavingsAccountTransactionData> {

    @Override
    public int compare(final SavingsAccountTransactionData o1, final SavingsAccountTransactionData o2) {
        int compareResult = 0;

        final int comparsion = o1.getTransactionDate().compareTo(o2.getLastTransactionDate());
        if (comparsion == 0) {
            compareResult = o1.getSubmittedOnDate().compareTo(o2.getSubmittedOnDate());
            if (compareResult == 0 && o1.getId() != null && o2.getId() != null) {
                compareResult = o1.getId().compareTo(o2.getId());
            } else {
                compareResult = comparsion;
            }
        } else {
            compareResult = comparsion;
        }
        return compareResult;
    }

}

==> apache-fineract-1.9.0-src.tar.gz: apache-fineract-src-1.9.0/fineract-provider/src/main/java/org/apache/fineract/portfolio/savings/domain/SavingsAccountTransactionDataComparator.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.portfolio.savings.domain;

import java.util.Comparator;
import org.apache.fineract.infrastructure.core.service.DateUtils;
import org.apache.fineract.portfolio.savings.data.SavingsAccountTransactionData;

public class SavingsAccountTransactionDataComparator implements Comparator<SavingsAccountTransactionData> {

    @Override
    public int compare(final SavingsAccountTransactionData o1, final SavingsAccountTransactionData o2) {
        int result = DateUtils.compare(o1.getTransactionDate(), o2.getTransactionDate());
        if (result != 0) {
            return result;
        }
        result = DateUtils.compare(o1.getSubmittedOnDate(), o2.getSubmittedOnDate());
        if (result != 0) {
            return result;
        }
        if (o1.getId() != null && o2.getId() != null) {
            return o1.getId().compareTo(o2.getId());
        }
        return 0;
    }

}
